PUNK PLUGIN README
===================

This directory contains the source files of the Pipeline UNit Keeper (PUNK), a plugin used to monitor and report the ROC pipeline activities.
PUNK is developed with and run under the POPPY framework.
